Module: MobileESPConverted

Defined in:
lib/mobileesp_converted/user_agent_info.rb,
lib/mobileesp_converted.rb,
lib/mobileesp_converted/version.rb

Overview

  • The DetectSmartPhone class encapsulates information about
  • a browser's connection to your web site.
  • You can use it to find out whether the browser asking for
  • your site's content is probably running on a mobile device.
  • The methods were written so you can be as granular as you want.
  • For example, enquiring whether it's as specific as an iPod Touch or
  • as general as a smartphone class device.
  • The object's methods return true, or false.

Defined Under Namespace

Classes: UserAgentInfo

Constant Summary collapse

VERSION =
"0.3.0"